%define anolis_release 3
Name:           e2fsprogs 
Version:        1.46.5 
Release:        %{anolis_release}%{?dist}
Summary:        Utilities for managing ext2, ext3, and ext4 file systems 
License:        GPLv2 
URL:            http://e2fsprogs.sourceforge.net/
Source0:        https://www.kernel.org/pub/linux/kernel/people/tytso/%{name}/v%{version}/%{name}-%{version}.tar.xz

Patch1:         0001-change-to-use-fuse3.patch

BuildRequires:  pkgconfig, texinfo, libselinux-devel, gcc
BuildRequires:  fuse-devel 
BuildRequires:  libsepol-devel
BuildRequires:  libblkid-devel
BuildRequires:  libuuid-devel
BuildRequires:  gettext
BuildRequires:  systemd
BuildRequires:  make
BuildRequires:  gnupg2 xz 
BuildRequires:  autoconf

Requires:       e2fsprogs-libs = %{version}-%{release}
Requires:       libcom_err = %{version}-%{release}
Requires:       libss = %{version}-%{release}      

Obsoletes: e4fsprogs < %{version}-%{release}
Provides: e4fsprogs = %{version}-%{release}

%description
The e2fsprogs package contains a number of utilities for creating,
checking, modifying, and correcting any inconsistencies in second,
third and fourth extended (ext2/ext3/ext4) file systems. E2fsprogs
contains e2fsck (used to repair file system inconsistencies after an
unclean shutdown), mke2fs (used to initialize a partition to contain
an empty ext2 file system), debugfs (used to examine the internal
structure of a file system, to manually repair a corrupted
file system, or to create test cases for e2fsck), tune2fs (used to
modify file system parameters), and most of the other core ext2fs
file system utilities.

You should install the e2fsprogs package if you need to manage the
performance of an ext2, ext3, or ext4 file system.

%package libs
Summary: Ext2/3/4 file system specific shared libraries
License: GPLv2 and LGPLv2
Requires: libcom_err = %{version}-%{release}

%description libs
E2fsprogs-libs contains libe2p and libext2fs, the libraries of the
e2fsprogs package.

These libraries are used to directly access ext2/3/4 file systems
from user space.

%package static
Summary: Ext2/3/4 file system specific static libraries
License: GPLv2 and LGPLv2

%description static
E2fsprogs-static contains all static libraries built from e2fsprogs,
including libext2fs, libcom_err, libe2p, and libss.

These libraries are used to directly access ext2/3/4 file systems
from user space, and perform other useful functions.

%package devel
Summary: Ext2/3/4 file system specific libraries and headers
License: GPLv2 and LGPLv2
Requires: e2fsprogs-libs = %{version}-%{release}
Requires: libcom_err-devel = %{version}-%{release}
Requires: gawk
Requires: pkgconfig

%description devel
E2fsprogs-devel contains the libraries and header files needed to
develop second, third and fourth extended (ext2/ext3/ext4)
file system specific programs.

You should install e2fsprogs-devel if you want to develop ext2/3/4
file system specific programs. If you install e2fsprogs-devel, you'll
also want to install e2fsprogs.

%package -n libcom_err
Summary: Common error description library
License: MIT

%description -n libcom_err
This is the common error description library, part of e2fsprogs.

libcom_err is an attempt to present a common error-handling mechanism.

%package -n libcom_err-devel
Summary: Common error description library
License: MIT
Requires: libcom_err = %{version}-%{release}
Requires: pkgconfig

%description -n libcom_err-devel
This is the common error description development library and headers,
part of e2fsprogs.  It contains the compile_et command, used
to convert a table listing error-code names and associated messages
messages into a C source file suitable for use with the library.

libcom_err is an attempt to present a common error-handling mechanism.

%package -n libss
Summary: Command line interface parsing library
License: MIT
Requires: libcom_err = %{version}-%{release}

%description -n libss
This is libss, a command line interface parsing library, part of e2fsprogs.

This package includes a tool that parses a command table to generate
a simple command-line interface parser, the include files needed to
compile and use it.

It was originally inspired by the Multics SubSystem library.

%package -n libss-devel
Summary: Command line interface parsing library
License: MIT
Requires: libss = %{version}-%{release}
Requires: pkgconfig

%description -n libss-devel
This is the command line interface parsing (libss) development library
and headers, part of e2fsprogs.  It contains the mk_cmds command, which
parses a command table to generate a simple command-line interface parser.

It was originally inspired by the Multics SubSystem library.

%package -n e2scrub
Summary: Online Ext4 metadata consistency checking tool and service
License: GPLv2 and LGPLv2
Recommends: sendmail
Requires: systemd
Requires: util-linux
Requires: lvm2
Requires: e2fsprogs = %{version}-%{release}

%description -n e2scrub
This package includes e2scrub script that can check ext[234] file system
metadata consistency while the file system is online. It also containes a
systemd service that can be enabled to do consistency check periodically.

The file system consistency check can be performed online and does not
require the file system to be unmounted. It uses lvm snapshots to do this
which means that it can only be done on file systems that are on a lvm
managed device with some free space available in respective volume group.


%prep
%autosetup -p1

rm -f configure
autoconf

rm -rf tests/m_rootdir_acl

%global _udevdir %{_prefix}/lib/udev/rules.d

%build
%global optflags %{optflags} -I%{_includedir}/fuse3
%configure CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
           --enable-elf-shlibs --enable-nls --disable-uuidd --disable-fsck \
           --disable-e2initrd-helper --disable-libblkid --disable-libuuid \
           --enable-quota --with-root-prefix=/usr --with-crond-dir=no
%make_build

%install
rm -rf $RPM_BUILD_ROOT
export PATH=/sbin:$PATH
%make_install install-libs \
        root_sbindir=%{_sbindir} root_libdir=%{_libdir}
chmod +w %{buildroot}%{_libdir}/*.a

%find_lang %{name}

%generate_compatibility_deps

%check
make PRINT_FAILED=yes fullcheck

%ldconfig_scriptlets libs

%ldconfig_scriptlets -n libcom_err

%ldconfig_scriptlets -n libss

%files -f %{name}.lang
%doc README
%{!?_licensedir:%global license %%doc}

%config(noreplace) %{_sysconfdir}/mke2fs.conf

%{_sbindir}/badblocks
%{_sbindir}/debugfs
%{_sbindir}/dumpe2fs
%{_sbindir}/e2fsck
%{_sbindir}/e2image
%{_sbindir}/e2label
%{_sbindir}/e2mmpstatus
%{_sbindir}/e2undo
%{_sbindir}/e4crypt
%{_sbindir}/fsck.ext2
%{_sbindir}/fsck.ext3
%{_sbindir}/fsck.ext4
%{_sbindir}/logsave
%{_sbindir}/mke2fs
%{_sbindir}/mkfs.ext2
%{_sbindir}/mkfs.ext3
%{_sbindir}/mkfs.ext4
%{_sbindir}/resize2fs
%{_sbindir}/tune2fs
%{_sbindir}/filefrag
%{_sbindir}/e2freefrag
%{_sbindir}/e4defrag
%{_sbindir}/mklost+found
%{abidir}/debugfs-option.list
%{abidir}/e4crypt-option.list

%{_bindir}/chattr
%{_bindir}/lsattr
%{_bindir}/fuse2fs
%{_mandir}/man1/chattr.1*
%{_mandir}/man1/fuse2fs.1*
%{_mandir}/man1/lsattr.1*

%{_mandir}/man5/ext2.5*
%{_mandir}/man5/ext3.5*
%{_mandir}/man5/ext4.5*
%{_mandir}/man5/e2fsck.conf.5*
%{_mandir}/man5/mke2fs.conf.5*

%{_mandir}/man8/badblocks.8*
%{_mandir}/man8/debugfs.8*
%{_mandir}/man8/dumpe2fs.8*
%{_mandir}/man8/e2fsck.8*
%{_mandir}/man8/e4crypt.8*
%{_mandir}/man8/filefrag.8*
%{_mandir}/man8/e2freefrag.8*
%{_mandir}/man8/e4defrag.8*
%{_mandir}/man8/fsck.ext2.8*
%{_mandir}/man8/fsck.ext3.8*
%{_mandir}/man8/fsck.ext4.8*
%{_mandir}/man8/e2image.8*
%{_mandir}/man8/e2label.8*
%{_mandir}/man8/e2mmpstatus.8*
%{_mandir}/man8/e2undo.8*
%{_mandir}/man8/logsave.8*
%{_mandir}/man8/mke2fs.8*
%{_mandir}/man8/mkfs.ext2.8*
%{_mandir}/man8/mkfs.ext3.8*
%{_mandir}/man8/mkfs.ext4.8*
%{_mandir}/man8/mklost+found.8*
%{_mandir}/man8/resize2fs.8*
%{_mandir}/man8/tune2fs.8*

%ifarch x86_64
%exclude %{_libdir}/e2fsprogs/e2scrub_all_cron
%endif

%files libs
%dir %{abidir}
%{!?_licensedir:%global license %%doc}
%license NOTICE
%{_libdir}/libe2p.so.*
%{_libdir}/libext2fs.so.*
%{abidir}/libe2p.dump
%{abidir}/libext2fs.dump

%files static
%{!?_licensedir:%global license %%doc}
%license NOTICE
%{_libdir}/*.a

%files devel
%{_infodir}/libext2fs.info*
%{_libdir}/libe2p.so
%{_libdir}/libext2fs.so
%{_libdir}/pkgconfig/e2p.pc
%{_libdir}/pkgconfig/ext2fs.pc

%{_includedir}/e2p
%{_includedir}/ext2fs

%files -n libcom_err
%{!?_licensedir:%global license %%doc}
%license NOTICE
%{_libdir}/libcom_err.so.*
%{abidir}/libcom_err.dump

%files -n libcom_err-devel
%{_bindir}/compile_et
%{_libdir}/libcom_err.so
%{_datadir}/et
%{_includedir}/et
%{_includedir}/com_err.h
%{_mandir}/man1/compile_et.1*
%{_mandir}/man3/com_err.3*
%{_libdir}/pkgconfig/com_err.pc

%files -n libss
%{!?_licensedir:%global license %%doc}
%license NOTICE
%{_libdir}/libss.so.*
%{abidir}/libss.dump

%files -n libss-devel
%{_bindir}/mk_cmds
%{_libdir}/libss.so
%{_datadir}/ss
%{_includedir}/ss
%{_mandir}/man1/mk_cmds.1*
%{_libdir}/pkgconfig/ss.pc

%files -n e2scrub
%config(noreplace) %{_sysconfdir}/e2scrub.conf
%{_sbindir}/e2scrub
%{_sbindir}/e2scrub_all
%{_mandir}/man8/e2scrub.8*
%{_mandir}/man8/e2scrub_all.8*
%{_libdir}/e2fsprogs/e2scrub_fail
%{_unitdir}/e2scrub@.service
%{_unitdir}/e2scrub_all.service
%{_unitdir}/e2scrub_all.timer
%{_unitdir}/e2scrub_fail@.service
%{_unitdir}/e2scrub_reap.service
%{_udevdir}/96-e2scrub.rules

%changelog
* Mon Oct 31 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.46.5-3
- optimise spec file 

* Tue Mar 22 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.46.5-2
- change to fuse3

* Tue Mar 08 2022 pangqing <pangqing@uniontech.com> - 1.46.5-1
- Init for anolisOS 23

